@@ -24,6 +24,7 @@ Support functions for date/time.
 """
 
 import datetime
+from string import Formatter
 from typing import Any, Optional, Union
 
 try:
@@ -35,7 +36,7 @@ try:
 except ImportError:
     dateutil = None
 import pendulum
-from pendulum import Date, Pendulum
+from pendulum import Date, Pendulum, Time
 import tzlocal
 
 PotentialDatetimeType = Union[None, datetime.datetime, datetime.date,
@@ -80,8 +81,8 @@ def coerce_to_pendulum(x: PotentialDatetimeType,
     # be altered; "tz" will only be applied in the absence of other info.
 
 
-def coerce_to_date(x: PotentialDatetimeType,
-                   assume_local: bool = False) -> Optional[Date]:
+def coerce_to_pendulum_date(x: PotentialDatetimeType,
+                            assume_local: bool = False) -> Optional[Date]:
     p = coerce_to_pendulum(x, assume_local=assume_local)
     if p is None:
         return None
@@ -89,12 +90,30 @@ def coerce_to_date(x: PotentialDatetimeType,
 
 
 def pendulum_to_datetime(x: Pendulum) -> datetime.datetime:
+    """
+    Used, for example, where a database backend insists on datetime.datetime.
+    """
     # noinspection PyProtectedMember
     return x._datetime
 
 
+def pendulum_date_to_datetime_date(x: Date) -> datetime.date:
+    """
+    Used, for example, where a database backend insists on datetime.date.
+    """
+    return datetime.date(year=x.year, month=x.month, day=x.day)
+
+
+def pendulum_time_to_datetime_time(x: Time) -> datetime.time:
+    """
+    Used, for example, where a database backend insists on datetime.time.
+    """
+    # noinspection PyProtectedMember
+    return x._time
+
+
 # =============================================================================
-# Format dates/times to strings
+# Format dates/times/timedelta to strings
 # =============================================================================
 
 def format_datetime(d: PotentialDatetimeType,
@@ -107,6 +126,61 @@ def format_datetime(d: PotentialDatetimeType,
     return d.strftime(fmt)
 
 
+def strfdelta(tdelta: Union[datetime.timedelta, int, float, str],
+              fmt='{D:02}d {H:02}h {M:02}m {S:02}s',
+              inputtype='timedelta'):
+    # Modified from:
+    # https://stackoverflow.com/questions/538666/python-format-timedelta-to-string  # noqa
+    """
+    Convert a datetime.timedelta object or a regular number to a custom-
+    formatted string, just like the strftime() method does for
+    datetime.datetime objects.
+
+    The fmt argument allows custom formatting to be specified.  Fields can
+    include seconds, minutes, hours, days, and weeks.  Each field is optional.
+
+    Some examples:
+        '{D:02}d {H:02}h {M:02}m {S:02}s' --> '05d 08h 04m 02s' (default)
+        '{W}w {D}d {H}:{M:02}:{S:02}'     --> '4w 5d 8:04:02'
+        '{D:2}d {H:2}:{M:02}:{S:02}'      --> ' 5d  8:04:02'
+        '{H}h {S}s'                       --> '72h 800s'
+
+    The inputtype argument allows tdelta to be a regular number instead of the
+    default, which is a datetime.timedelta object.  Valid inputtype strings:
+        's', 'seconds',
+        'm', 'minutes',
+        'h', 'hours',
+        'd', 'days',
+        'w', 'weeks'
+    """
+
+    # Convert tdelta to integer seconds.
+    if inputtype == 'timedelta':
+        remainder = int(tdelta.total_seconds())
+    elif inputtype in ['s', 'seconds']:
+        remainder = int(tdelta)
+    elif inputtype in ['m', 'minutes']:
+        remainder = int(tdelta) * 60
+    elif inputtype in ['h', 'hours']:
+        remainder = int(tdelta) * 3600
+    elif inputtype in ['d', 'days']:
+        remainder = int(tdelta) * 86400
+    elif inputtype in ['w', 'weeks']:
+        remainder = int(tdelta) * 604800
+    else:
+        raise ValueError("Bad inputtype: {}".format(inputtype))
+
+    f = Formatter()
+    desired_fields = [field_tuple[1] for field_tuple in f.parse(fmt)]
+    possible_fields = ('W', 'D', 'H', 'M', 'S')
+    constants = {'W': 604800, 'D': 86400, 'H': 3600, 'M': 60, 'S': 1}
+    values = {}
+    for field in possible_fields:
+        if field in desired_fields and field in constants:
+            values[field], remainder = divmod(remainder, constants[field])
+    return f.format(fmt, **values)
+
+
 # =============================================================================
 # Time zones themselves
 # =============================================================================
